@@ -1,6 +1,7 @@
 # pylint: disable=E1101,R0201,W0613
 
 #!/usr/bin/env python3
+import itertools
 import json
 import os
 import time
@@ -369,8 +370,6 @@ class Stream():
     def transform(self, record):
         return humps.decamelize(record)
 
-    LOG_PROGRESS_PERCENTAGE_INTERVAL = 5
-
     def sync_substream(self, state, parent, sub_stream, parent_response):
         bookmark_date = self.get_bookmark(state, sub_stream.name,
                                           self.config.get('start_date'),
@@ -389,15 +388,18 @@ class Stream():
 
         # Slice response for >= last processed
         if last_processed:
-            for i, e in enumerate(parent_response):
-                if e.get(parent.key_properties[0]) == last_processed:
-                    LOGGER.info("Resuming %s sync with %s", sub_stream.name, e.get(parent.key_properties[0]))
-                    parent_response = parent_response[i:len(parent_response)]
-                    continue
+            i = 0
+            for response in parent_response:
+                if response.get(parent.key_properties[0]) == last_processed:
+                    LOGGER.info("Resuming %s sync with %s", sub_stream.name, response.get(parent.key_properties[0]))
+                    if isinstance(parent_response, list):
+                        parent_response = parent_response[i:]
+                    else:
+                        parent_response = itertools.chain([response], parent_response)
+                    break
+                i += 1
 
-
-        next_log_progress_percentage = 0
-        for index, record in enumerate(parent_response):
+        for record in parent_response:
             try:
                 with metrics.record_counter(
                         sub_stream.name) as counter, Transformer(
@@ -444,11 +446,6 @@ class Stream():
             self.update_bookmark(state=state, stream=sub_stream.name, bookmark_value=record.get(parent.key_properties[0]), bookmark_key="last_processed")
             self.update_bookmark(state=state, stream=sub_stream.name, bookmark_value=strftime(new_bookmark), bookmark_key=sub_stream.replication_key)
 
-            progress_percentage = float(index) / len(parent_response) * 100
-            if progress_percentage > next_log_progress_percentage:
-                LOGGER.info("Finished syncing %s percentage of sub_stream for parent %s's sub_stream %s data", progress_percentage, parent.name, sub_stream.name)
-                next_log_progress_percentage += self.LOG_PROGRESS_PERCENTAGE_INTERVAL
-
         # After processing for all parent ids we can remove our resumption state
         state.get('bookmarks').get(sub_stream.name).pop('last_processed')
         update_currently_syncing(state, None)
@@ -739,7 +736,7 @@ class TrackEvents(EventsBase):
                 "pipeline": [{
                     "source": {
                         "trackEvents": {
-                            "trackId": key_id
+                            "trackTypeId": key_id
                         },
                         "timeSeries": {
                             "period": period,
@@ -968,19 +965,21 @@ class Visitors(LazyAggregationStream):
         return "/api/v1/aggregation"
 
     def get_body(self):
+        include_anonymous_visitors = bool(self.config.get('include_anonymous_visitors', 'false').lower() == 'true')
         return {
             "response": {
                 "mimeType": "application/json"
             },
             "request": {
-                "name": "all-visitors",
-                "pipeline": [
-                    {
-                        "source": {
-                            "visitors": None
+                "name":
+                "all-visitors",
+                "pipeline": [{
+                    "source": {
+                        "visitors": {
+                            "identified": not include_anonymous_visitors
                         }
                     }
-                ],
+                }],
                 "requestId": "all-visitors",
                 "sort": [
                     "visitorId"
